@@ -40,6 +40,13 @@ use Capture::Tiny qw( capture_merged );
   }
 }
 
+sub vcpkg
+{
+  return unless $Config{ccname} eq 'cl';
+  require Alien::FFI::Vcpkg;
+  !!eval { Alien::FFI::Vcpkg->vcpkg }
+}
+
 sub myWriteMakefile
 {
   my %args = @_;
@@ -59,6 +66,14 @@ sub myWriteMakefile
     Alien::Base::Wrapper->import( 'Alien::FFI', 'Alien::psapi', '!export' );
     %alien = Alien::Base::Wrapper->mm_args;
   }
+  elsif(vcpkg())
+  {
+    print "using vcpkg libffi package\n";
+    $build_config->set(alien => { class => 'Alien::FFI::Vcpkg', mode => 'system' });
+    require Alien::Base::Wrapper;
+    Alien::Base::Wrapper->import( 'Alien::FFI::Vcpkg', '!export');
+    %alien = Alien::Base::Wrapper->mm_args;
+  }
   else
   {
     require Alien::FFI::pkgconfig    if $^O ne 'MSWin32';
@@ -171,6 +186,8 @@ sub myWriteMakefile
 
 package MY;
 
+use Config;
+
 sub dynamic_lib
 {
   my($self, @therest) = @_;
@@ -227,67 +244,79 @@ sub postamble {
 
   my $noecho = !!$ENV{V} ? '' : '$(NOECHO) ';
 
+  my $sep = $^O eq 'MSWin32' && $Config{make} eq 'nmake'
+    ? '\\'
+    : '/';
+
   $postamble .=
-    "flags: _mm/flags\n" .
-    "_mm/flags:\n";
+    "flags: _mm${sep}flags\n" .
+    "_mm${sep}flags:\n";
 
   foreach my $key (qw( cc inc ccflags cccdlflags optimize ld ldflags lddlflags ))
   {
     $postamble .=
-      sprintf "\t$noecho\$(FULLPERL) inc/mm-config-set.pl %-20s \$(%s)\n", $key, uc $key;
+      sprintf "\t$noecho\$(FULLPERL) inc${sep}mm-config-set.pl %-20s \$(%s)\n", $key, uc $key;
   }
 
   $postamble .=
     "\t$noecho\$(MKPATH) _mm\n" .
-    "\t$noecho\$(TOUCH) _mm/flags\n\n";
+    "\t$noecho\$(TOUCH) _mm${sep}flags\n\n";
 
   $postamble .=
-    "probe-runner-builder prb: _mm/probe-builder\n" .
-    "_mm/probe-builder: _mm/flags\n" .
-    "\t$noecho\$(FULLPERL) inc/mm-config-pb.pl\n" .
+    "probe-runner-builder prb: _mm${sep}probe-builder\n" .
+    "_mm${sep}probe-builder: _mm${sep}flags\n" .
+    "\t$noecho\$(FULLPERL) inc${sep}mm-config-pb.pl\n" .
     "\t$noecho\$(MKPATH) _mm\n" .
-    "\t$noecho\$(TOUCH) _mm/probe-builder\n\n";
+    "\t$noecho\$(TOUCH) _mm${sep}probe-builder\n\n";
 
   $postamble .=
-    "config :: _mm/config\n" .
-    "_mm/config: _mm/flags _mm/probe-builder\n" .
-    "\t$noecho\$(FULLPERL) inc/mm-config.pl\n" .
+    "config :: _mm${sep}config\n" .
+    "_mm${sep}config: _mm${sep}flags _mm${sep}probe-builder\n" .
+    "\t$noecho\$(FULLPERL) inc${sep}mm-config.pl\n" .
     "\t$noecho\$(MKPATH) _mm\n" .
-    "\t$noecho\$(TOUCH) _mm/config\n\n";
+    "\t$noecho\$(TOUCH) _mm${sep}config\n\n";
 
   $postamble .=
     "pure_all :: ffi\n" .
-    "ffi: _mm/config\n" .
-    "\t$noecho\$(FULLPERL) inc/mm-build.pl\n\n";
+    "ffi: _mm${sep}config\n" .
+    "\t$noecho\$(FULLPERL) inc${sep}mm-build.pl\n\n";
 
   $postamble .=
     "subdirs-test_dynamic subdirs-test_static subdirs-test :: ffi-test\n" .
-    "ffi-test : _mm/config\n" .
-    "\t$noecho\$(FULLPERL) inc/mm-test.pl\n\n";
+    "ffi-test : _mm${sep}config\n" .
+    "\t$noecho\$(FULLPERL) inc${sep}mm-test.pl\n\n";
 
   $postamble .=
     "clean :: mm-clean\n" .
     "mm-clean :\n" .
-    "\t$noecho\$(FULLPERL) inc/mm-clean.pl\n" .
-    "\t$noecho\$(RM_RF) _mm ffi-probe-*\n\n";
+    "\t$noecho\$(FULLPERL) inc${sep}mm-clean.pl\n" .
+    "\t$noecho\$(RM_RF) _mm ffi-probe-*\n" .
+    "\t$noecho\$(RM_RF) .tmp\n" .
+    "\t$noecho\$(RM_RF) corpus${sep}*${sep}*${sep}tmpbuild*\n\n";
 
-  if(1)
+  # Workaround for the tireless testers out there
+  # who want to make -jX a thing.  For some reason.
+  #
+  # When bsd make is passed -jX it turns off compat
+  # mode, even if the Makefile itself turns off
+  # parallel build.  Unfortunately the Makefile
+  # generated by EUMM does not work without compat
+  # mode.  So we:
+  $postamble .=
+    # 1. turn off parallel build using the bsd-only
+    #    faux rule `.NO_PARALLEL` rather than the
+    #    more portable `.NOTPARALLEL`, because this
+    #    will allow parallel build with gmake, which
+    #    does work.
+    ".NO_PARALLEL:\n\n";
+
+  if($^O eq 'MSWin32' && $Config{ccname} eq 'cl')
+  {
+    # nothing.
+  }
+  else
   {
-    # Workaround for the tireless testers out there
-    # who want to make -jX a thing.  For some reason.
-    #
-    # When bsd make is passed -jX it turns off compat
-    # mode, even if the Makefile itself turns off
-    # parallel build.  Unfortunately the Makefile
-    # generated by EUMM does not work without compat
-    # mode.  So we:
     $postamble .=
-      # 1. turn off parallel build using the bsd-only
-      #    faux rule `.NO_PARALLEL` rather than the
-      #    more portable `.NOTPARALLEL`, because this
-      #    will allow parallel build with gmake, which
-      #    does work.
-      ".NO_PARALLEL:\n\n" .
       # 2. turn compat mode back on.
       ".MAKE.MODE=compat\n\n";
   }
