@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -174,6 +174,9 @@ sub lang
 }
 
 
+sub api { shift->{api} }
+
+
 sub type
 {
   my($self, $name, $alias) = @_;
@@ -525,7 +528,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 1.09
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -767,6 +770,14 @@ Platypus to find symbols using the demangled names (for example, if you
 specify L<CPP|FFI::Platypus::Lang::CPP> for C++ you can use method names
 like C<Foo::get_bar()> with L</attach> or L</function>.
 
+=head2 api
+
+[version 1.11]
+
+ my $level = $ffi->api;
+
+Returns the API level of the Platypus instance.
+
 =head1 METHODS
 
 =head2 type
@@ -2219,9 +2230,9 @@ recent versions of Perl.
 
 =item L<FFI>
 
-Foreign function interface based on (nomenclature is everything) FSF's
-C<ffcall>. It hasn't worked for quite some time, and C<ffcall> is no
-longer supported or distributed.
+Older, simpler, less featureful FFI.  It used to be implemented
+using FSF's C<ffcall>.  Because C<ffcall> has been unsupported for
+some time, I reimplemented this module using L<FFI::Platypus>.
 
 =item L<C::DynaLib>
 
@@ -2246,9 +2257,11 @@ under development anymore.
 
 In addition to the contributors mentioned below, I would like to
 acknowledge Brock Wilcox (AWWAIID) and Meredith Howard (MHOWARD) whose
-work on L<FFI::Sweet|https://github.com/merrilymeredith/p5-FFI-Sweet>
-not only helped me get started with FFI but significantly influenced the
-design of Platypus.
+work on C<FFI::Sweet> not only helped me get started with FFI but
+significantly influenced the design of Platypus.
+
+Dan Book, who goes by Grinnz on IRC for answering user questions about
+FFI and Platypus.
 
 In addition I'd like to thank Alessandro Ghedini (ALEXBIO) whose work
 on another Perl FFI library helped drive some of the development ideas
@@ -2288,6 +2301,8 @@ Håkon Hægland (hakonhagland, HAKONH)
 
 Meredith (merrilymeredith, MHOWARD)
 
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
