@@ -2,7 +2,6 @@
 #include "perl.h"
 #include "XSUB.h"
 #include "ppport.h"
-
 #include "ffi_platypus.h"
 
 /*
@@ -23,9 +22,10 @@
 size_t
 ffi_pl_sizeof_new(ffi_pl_type *self)
 {
-  switch( self->type_code & (FFI_PL_SHAPE_SCALAR | FFI_PL_SHAPE_POINTER | FFI_PL_SHAPE_ARRAY) )
+  switch( self->type_code & FFI_PL_SHAPE_MASK )
   {
     case FFI_PL_SHAPE_SCALAR:
+    case FFI_PL_SHAPE_CUSTOM_PERL:
       return unit_size(self);
     case FFI_PL_SHAPE_POINTER:
       return sizeof(void*);
@@ -43,6 +43,10 @@ ffi_pl_sizeof(ffi_pl_type *self)
   {
     return self->extra[0].record.size;
   }
+  else if(self->type_code == FFI_PL_TYPE_RECORD_VALUE)
+  {
+    return self->extra[0].record_value.size;
+  }
   else
   {
     return ffi_pl_sizeof_new(self);
@@ -116,6 +120,12 @@ ffi_pl_get_type_meta(ffi_pl_type *self)
             hv_store(meta, "ref",           3, newSViv(self->extra[0].record.stash != NULL ? 1 : 0),0);
             break;
 
+          case FFI_PL_TYPE_RECORD_VALUE:
+            hv_store(meta, "type",          4, newSVpv("record_value",0),0);
+            hv_store(meta, "ref",           3, newSViv(1),0);
+            hv_store(meta, "class",         5, newSVpv(self->extra[0].record_value.class,0), 0);
+            break;
+
           default:
             hv_store(meta, "element_size", 12, newSViv(unit_size(self)), 0);
             hv_store(meta, "type",          4, newSVpv("scalar",0),0);
@@ -229,6 +239,9 @@ ffi_pl_get_type_meta(ffi_pl_type *self)
     case FFI_PL_TYPE_RECORD:
       string = "pointer";
       break;
+    case FFI_PL_TYPE_RECORD_VALUE:
+      string = "struct";
+      break;
 #ifdef FFI_TARGET_HAS_COMPLEX_TYPE
     case FFI_PL_TYPE_COMPLEX_FLOAT:
       string = "complex_float";
